@@ -34,7 +34,7 @@ void GErrC(GNeuron *GMatrix,int GNIndex,float Err,int CheckType)
     float GNS;			//GNeuron Summary
     
     //Print Message
-    printf("* Error Correction At Neuron %i *\n\n",GNIndex+1);
+    printf("* Error Correction At GNeuron %i *\n\n",GNIndex+1);
     
     //Get GNeuron Function Type
     GNFT=GMatrix[GNIndex].GetNFT();
