@@ -33,8 +33,9 @@ float GErrStat(float *FirstData,float *LastData,float *AltData,int StatType)
     int Faults;			//Faults Counter
     float OK,Error;		//OK And Error Values (%)
     
-    //Reset OK,Error
-    OK=Error=0.0;
+    //Reset Statistics
+    OK=0.0;
+    Error=0.0;
     
     //Reset Tracer;
     Y=0;
@@ -43,7 +44,7 @@ float GErrStat(float *FirstData,float *LastData,float *AltData,int StatType)
     Faults=0;
     
     //Check Statistics Type
-    if (StatType<0 || StatType>1)
+    if (StatType<0 OR StatType>1)
     
     {
     
@@ -114,10 +115,10 @@ float GErrStat(float *FirstData,float *LastData,float *AltData,int StatType)
         
         printf("Correct:%.1f%\n",OK);
         printf("Error:%.1f%\n\n",Error);
-        
-        return Error;
     
     }
+    
+    return Error;
 
 }
 
