@@ -35,15 +35,14 @@ void GNMS(int SimFunc)
     int NLE;			//Next Layer End
     int GNFT;			//GNeuron Function Type
     int Tracer;			//A Tracer
+    int Offset;			//Geeks Hash Table Offset
     float NewData[MAX_PIN];	//New Data From Inputs GSocket
-    float GMinData[MAX_PIN];	//Min Data Value Produced By G.A.N.N
-    float GMaxData[MAX_PIN];	//Max Data Value Produced By G.A.N.N
     float AccErr;		//Acceptable Error (%)
     float GErr;			//G.A.N.N Error (%)
     float Tmp;			//Temp Values
     
     //Check For Wrong Simulation Mode
-    if (SimFunc<0 || SimFunc>2)
+    if (SimFunc<0 OR SimFunc>2)
     
     {
     
@@ -53,32 +52,32 @@ void GNMS(int SimFunc)
     
     }
     
-    //Create A New G.A.N.N In Memory (G.A.N.N Matrix)
-    GNeuron *GANN;
-    GANN = new GNeuron[GNNum];
-    
-    //Get I/O From GSockets Loaded In Memory
-    Inputs=InSocket.GetPins();
-    Outputs=OutSocket.GetPins();
-    
-    //Get Acceptable Error
-    AccErr=100.0-Threshold;
-    
-    //Fill NData With Inputs GSocket Data (Only For Uniform Checks)
-    for (i=0;i<Inputs;i++)
-        NewData[i]=InSocket.GetPV(i,0);
-    
-    //Check GMap Simulation Type So As To Set GNeurons Function Type
-    if (GMSType==0)
-        GNFT=0;
-    else
-        GNFT=2;
-    
     //Learn
     if (SimFunc==0)
     
     {
     
+        //Create A New G.A.N.N In Memory (G.A.N.N Matrix)
+        GNeuron *GANN;
+        GANN=new GNeuron[MAX_GN];
+        
+        //Get I/O From GSockets Loaded In Memory
+        Inputs=InSocket.GetPins();
+        Outputs=OutSocket.GetPins();
+        
+        //Get Acceptable Error
+        AccErr=100.0-LearnTH;
+        
+        //Fill NData With Inputs GSocket Data (Only For Uniform Checks)
+        for (i=0;i<Inputs;i++)
+            NewData[i]=InSocket.GetPV(i,0);
+        
+        //Check GMap Simulation Type So As To Set GNeurons Function Type
+        if (GMSType==0)
+            GNFT=0;
+        else
+            GNFT=2;
+        
         //Print Inputs GSocket
         printf("----- Inputs GSocket -----\n");   
         
@@ -98,7 +97,8 @@ void GNMS(int SimFunc)
         
         printf("--------------------------\n\n");
         
-        printf("Start Learning...\n\n");
+        //Start Simulation
+        printf("Learning...\n\n");
         
         //Simulations Loop
         for (n=0;n<SimNum;n++)
@@ -164,11 +164,6 @@ void GNMS(int SimFunc)
                                 GANN[GNC].InData(p,Tmp);
                             
                             }
-                            
-                            //Enable This GNeuron
-                            GANN[GNC].Enable(GNFT);
-                            
-                            printf("Neuron %i Enabled!\n\n",GNC+1);
                         
                         }
                         
@@ -185,13 +180,13 @@ void GNMS(int SimFunc)
                                 GANN[GNC].InData(p-NLH,GANN[p].OutData());
                             
                             }
-                            
-                            //Enable This GNeuron
-                            GANN[GNC].Enable(GNFT);
-                            
-                            printf("Neuron %i Enabled!\n\n",GNC+1);
                         
                         }
+                        
+                        //Enable This GNeuron
+                        GANN[GNC].Enable(GNFT);
+                        
+                        printf("GNeuron %i Enabled!\n\n",GNC+1);
                     
                     }
                     
@@ -296,13 +291,13 @@ void GNMS(int SimFunc)
                     
                         Tmp=OutSocket.GetPV(i,1);
                         
-                        if (OutSocket.GetPV(i,1)!=0.0 &&\
+                        if (OutSocket.GetPV(i,1)!=0.0 AND\
                         (GANN[j].OutData()*Tmp)>OutSocket.GetPV(i,1))
                             GErrC(GANN,j,GErr,AUTO);
                         
                         Tmp=OutSocket.GetPV(i,0);
                         
-                        if (OutSocket.GetPV(i,1)==0.0 &&\
+                        if (OutSocket.GetPV(i,1)==0.0 AND\
                         (GANN[j].OutData()*Tmp)>OutSocket.GetPV(i,0))
                             GErrC(GANN,j,GErr,AUTO);
                         
@@ -318,6 +313,9 @@ void GNMS(int SimFunc)
             }
         
         }
+        
+        //Unload G.A.N.N From Memory
+        delete []GANN;
     
     }
     
@@ -326,18 +324,182 @@ void GNMS(int SimFunc)
     
     {
     
-        //Run GRMC For User Interaction
-        GRMC();
+        //Reset Offset
+        Offset=-1;
+        
+        //Run GRMC (User Interaction - Get User Values Number)
+        n=GRMC();
+        
+        //Create A New G.A.N.N In Memory (G.A.N.N Matrix)
+        GNeuron *GANN;
+        GANN=new GNeuron[MAX_GN];
         
         //Start Simulation
+        printf("Running...\n\n");
         
+        //Escape Caption
+        ReRun:;
+        
+        //Increase Offset
+        if (Offset<n-1)
+            Offset++;
+        
+        //Read GKDB And Load It To G.A.N.N
+	GReadData(GANN,Offset);
+	
+	//Check User Values Number
+	if (n>Inputs)
+	
+	{
+	
+	    printf("Error: User Values Number Are More Than Inputs!\n");
+	    
+	    exit(1);
+	
+	}
+	
+	//Check GMap Simulation Type So As To Set GNeurons Function Type
+	if (GMSType==0)
+	    GNFT=0;
+	else
+	    GNFT=2;
+	
+        //Reset Tracer
+        Tracer=0;
+        
+        //Reset GNC
+        GNC=-1;
+        
+        //Reset NLH
+        NLH=0;
+        
+        //Reset NLE
+        NLE=0;
+        
+        //Start Routing Through The Layers
+        for (i=0;i<Layers;i++)
+        
+        {
+        
+            //Get GNeurons Of Current Layer
+            k=GMap[i];
+            
+            //Check GMap Connections Type (0:Auto,1:Manual)
+            if (GMCType==0)
+            
+            {
+            
+                //Enable All GNeurons
+                for (j=NLE;j<(k+NLE);j++)
+                
+                {
+                
+                    //GNeurons Counter
+                    GNC++;
+                    
+                    //Give Data To GNeurons Of The First Layer
+                    if (i==0)
+                    
+                    {
+                    
+                        for (p=0;p<Inputs;p++)
+                            GANN[GNC].InData(p-NLH,UserVal[Offset]);
+                    
+                    }
+                    
+                    else
+                    
+                    {
+                    
+                        //Give Data To GNeurons Of The Rest Layers
+                        for (p=NLH;p<(NLH+NLE);p++)
+                            GANN[GNC].InData(p-NLH,GANN[p].OutData());
+                    
+                    }
+                    
+                    //Run This GNeuron
+                    GANN[GNC].Run(GNFT);
+                
+                }
+                
+                //Next Layer Head
+                NLH+=NLE;
+                
+                //Next Layer End
+                NLE=k;
+            
+            }
+            
+            else
+            
+            {
+            
+                //User Defined Connections
+                
+            
+            }
+        
+        }
+        
+        //Get G.A.N.N Values
+        for (i=NLH;i<(NLH+NLE);i++)
+        
+        {
+        
+            if (GANN[i].OutData()*GMinData[i-NLH]==GMinData[i-NLH]\
+            OR GMaxData[i-NLH]!=0.0\
+            AND GANN[i].OutData()*GMaxData[i-NLH]<=GMaxData[i-NLH])
+            
+            {
+            
+                if (RunTH<LearnTH)
+                
+                {
+                
+                    printf("\n* Output GPin%i *\n",Offset+1);
+                    printf("Found Value With Little Acurracy!\n\n");
+                
+                }
+                
+                else
+                
+                {
+                
+                    printf("\n* Output GPin%i *\n",Offset+1);
+                    printf("Value Found!\n\n");
+                
+                }
+                
+                if (Offset==n-1)
+                    break;
+                else
+                    goto ReRun;
+            
+            }
+            
+            else if (Offset==n-1)
+            
+            {
+            
+                printf("Nothing Found...Finished!\n");
+                
+                break;
+            
+            }
+            
+            printf("Nothing Found...System Will Rerun!\n\n");
+            
+            goto ReRun;
+        
+        }
+        
+        //Unload G.A.N.N From Memory
+        delete []GANN;
     
     }
     
-    //Unload G.A.N.N From Memory (G.A.N.N Matrix)
-    delete [] GANN;
-    
     //Clean Up
+    system("touch GIOD GMap");
     system("rm GIOD GMap");
 
 }
