@@ -23,48 +23,76 @@
 
 
 //Geeks Read Data (Function)
-int GReadData(GNeuron *GMatrix,int RegNum)
+void GReadData(GNeuron *GMatrix,int RegNum)
 
 {
 
     //Variables
-    int i,j;
+    int i,j,k;
     float d;
     FILE *FileToOpen;
     
+    //Reset j
+    j=0;
+    
+    //Initialize GHT
+    FileToOpen=fopen("GHT","r");
+    
+    //Read Offset
+    for (i=0;i<RegNum-1;i++)
+        fscanf(FileToOpen,"%i\n",&j);
+    
+    //Close GHT
+    fclose(FileToOpen);
+    
     //Initialize GKDB
     FileToOpen=fopen("GKDB","r");
     
-    //Get Starting Header
-    fscanf(FileToOpen,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",\
-    SimNum,ECT,GMSType,GMCType,Threshold,GNNum,Layers,Inputs,Outputs);
+    //Set Pointer To Right Offset
+    fseek(FileToOpen,j,SEEK_SET);
     
+    //Read Starting Header
+    fscanf(FileToOpen,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",\
+    &SimNum,&ECT,&GMSType,&GMCType,&LearnTH,&GNNum,&Layers,&Inputs,&Outputs);
+    
+    //Read GMap Layers
+    for (i=0;i<Layers;i++)
+        fscanf(FileToOpen,"%i\n",&GMap[i]);
+    
+    //Read GNeurons Options
     for (i=0;i<GNNum;i++)
     
     {
     
-        for (j=0;j<Inputs;j++)
+        //Read Input Slot Pins Of This GNeuron
+        fscanf(FileToOpen,"%i\n",&k);
+        
+        for (j=0;j<k;j++)
         
         {
         
-            fscanf(FileToOpen,"%f\n",d);
-            GMatrix[i].InData(j,d);
-            fscanf(FileToOpen,"%f\n",d);
+            fscanf(FileToOpen,"%f\n",&d);
             GMatrix[i].SetWeights(j,d);
         
         }
         
-        fscanf(FileToOpen,"%i\n",d);
-        GMatrix[i].SetNFT((int)d);
-        fscanf(FileToOpen,"%f\n",d);
-        GMatrix[i].SetSum(d);
-        fscanf(FileToOpen,"%f\n",d);
-        GMatrix[i].SetBase(d);
-        fscanf(FileToOpen,"%f\n",d);
+        fscanf(FileToOpen,"%i\n",&j);
+        GMatrix[i].SetNFT(j);
+        fscanf(FileToOpen,"%f\n",&d);
         GMatrix[i].Mod=d;
     
     }
     
+    //Read Output Socket Values
+    for (i=0;i<Outputs;i++)
+    
+    {
+    
+        fscanf(FileToOpen,"%f\n",&GMinData[i]);
+        fscanf(FileToOpen,"%f\n",&GMaxData[i]);
+    
+    }
+    
     //Close GKDB
     fclose(FileToOpen);
 
