@@ -23,7 +23,7 @@
 
 
 //Geeks Remove Data (Function)
-void GRemData()
+void GRemData(GNeuron *GMatrix,int RegNum)
 
 {
 
